EXPORTS
	??1CSsmUiSpecific@@UAE@XZ @ 1 NONAME ; CSsmUiSpecific::~CSsmUiSpecific(void)
	?EmergencyCallPropertyCategory@CSsmUiSpecific@@SA?AVTUid@@XZ @ 2 NONAME ; class TUid CSsmUiSpecific::EmergencyCallPropertyCategory(void)
	?EmergencyCallPropertyKey@CSsmUiSpecific@@SAIXZ @ 3 NONAME ; unsigned int CSsmUiSpecific::EmergencyCallPropertyKey(void)
	?InstanceL@CSsmUiSpecific@@SAPAV1@XZ @ 4 NONAME ; class CSsmUiSpecific * CSsmUiSpecific::InstanceL(void)
	?IsSimSupported@CSsmUiSpecific@@SAHXZ @ 5 NONAME ; int CSsmUiSpecific::IsSimSupported(void)
	?Release@CSsmUiSpecific@@SAXXZ @ 6 NONAME ; void CSsmUiSpecific::Release(void)
	0 @ 7 ABSENT; absent
	?StartupPSUid@CSsmUiSpecific@@SA?AVTUid@@XZ @ 8 NONAME ; class TUid CSsmUiSpecific::StartupPSUid(void)
	?SecurityPinNotifierUid@CSsmUiSpecific@@SA?AVTUid@@XZ @ 9 NONAME ; class TUid CSsmUiSpecific::SecurityPinNotifierUid(void)
	?ScreenOutputChannelUid@CSsmUiSpecific@@SA?AVTUid@@XZ @ 10 NONAME ; class TUid CSsmUiSpecific::ScreenOutputChannelUid(void)
	?SecurityStatus@CSsmUiSpecific@@QBE?AW4TStrtSecurityStatus@@XZ @ 11 NONAME ; enum TStrtSecurityStatus CSsmUiSpecific::SecurityStatus(void) const
	?SetSecurityStatus@CSsmUiSpecific@@QAEXABW4TStrtSecurityStatus@@@Z @ 12 NONAME ; void CSsmUiSpecific::SetSecurityStatus(enum TStrtSecurityStatus const &)
	?IsSimlessOfflineSupported@CSsmUiSpecific@@SAHXZ @ 13  NONAME ; int CSsmUiSpecific::IsSimlessOfflineSupported(void)
	?SimStatusPropertyKey@CSsmUiSpecific@@SAIXZ @ 14 NONAME ; unsigned int CSsmUiSpecific::SimStatusPropertyKey(void)
	?IsSimStateChangeAllowed@CSsmUiSpecific@@SAHXZ @ 15 NONAME ; int CSsmUiSpecific::IsSimStateChangeAllowed(void)
	?IsAmaStarterSupported@CSsmUiSpecific@@SAHXZ @ 16 NONAME ; int CSsmUiSpecific::IsAmaStarterSupported(void)
	?GetTsyModuleNameL@CSsmUiSpecific@@SAPAVHBufC16@@XZ @ 17 NONAME ; class HBufC16 * CSsmUiSpecific::GetTsyModuleNameL(void)
	?StarterPSUid@CSsmUiSpecific@@SA?AVTUid@@XZ @ 18 NONAME ; class TUid CSsmUiSpecific::StarterPSUid(void)
	?PhoneTsyNameL@CSsmUiSpecific@@SAPAVHBufC16@@XZ @ 19 NONAME ; class HBufC16 * CSsmUiSpecific::PhoneTsyNameL(void)
	?IsSimPresent@CSsmUiSpecific@@SAHXZ @ 20 NONAME ; int CSsmUiSpecific::IsSimPresent(void)
	?IsNormalBoot@CSsmUiSpecific@@SAHXZ @ 21  NONAME ; int CSsmUiSpecific::IsNormalBoot(void)
	?IsSimChangedReset@CSsmUiSpecific@@SAHXZ @ 22  NONAME ; int CSsmUiSpecific::IsSimChangedReset(void)
	?RFStatusPropertyKey@CSsmUiSpecific@@SAIXZ @ 23  NONAME ; unsigned int CSsmUiSpecific::RFStatusPropertyKey(void)
	?RFStatusPropertyCategory@CSsmUiSpecific@@SA?AVTUid@@XZ @ 24  NONAME ; class TUid CSsmUiSpecific::RFStatusPropertyCategory(void)
	?ValidateRTCPropertyKey@CSsmUiSpecific@@SAIXZ @ 25  NONAME ; unsigned int CSsmUiSpecific::ValidateRTCPropertyKey(void)
	?ValidateRTCPropertyCategory@CSsmUiSpecific@@SA?AVTUid@@XZ @ 26  NONAME ; class TUid CSsmUiSpecific::ValidateRTCPropertyCategory(void)
	?PhoneMemoryRootDriveId@CSsmUiSpecific@@SAHXZ @ 27  NONAME ; int CSsmUiSpecific::PhoneMemoryRootDriveId(void)
	?ReservePhoneMemorySpace@CSsmUiSpecific@@QAEHXZ @ 28  NONAME ; int CSsmUiSpecific::ReservePhoneMemorySpace(void)
	?FreeReservedPhoneMemorySpace@CSsmUiSpecific@@QAEHH@Z @ 29  NONAME ; int CSsmUiSpecific::FreeReservedPhoneMemorySpace(int)
